RaiserMiddleware class

Marks a class as a Raiser middleware for code generation.

The generator will auto-discover classes with this annotation and generate registration code.

@RaiserMiddleware()
class LoggingMiddleware implements Middleware {
  @override
  Future<void> call(event, next) async {
    print('Event: $event');
    await next();
  }
}

Constructors

RaiserMiddleware({int priority = 0, String? busName})
const

Properties

busName String?
Optional bus name for named bus registration.
final
hashCode int
The hash code for this object.
no setterinherited
priority int
Optional priority for middleware execution order. Higher values execute first (outer middleware).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited